@@ -12,11 +12,13 @@ class TestBatchProcessor(unittest.TestCase):
 
     def setUp(self):
         # multiprocessing.set_start_method('spawn') # spawn doesn't work here https://bugs.python.org/issue33884
-        self.processor = BatchProcessor(self.batch_func, worker_num=2)
-
+        self.processor_1 = BatchProcessor(self.batch_func, worker_num=2)
+        self.processor_2 = BatchProcessor(self.batch_func, worker_num=2, task_wait_time=0.001)
 
     def test_process(self):
-        self.assertEqual(self.processor.process(5), 10)
+        self.assertEqual(self.processor_1.process(5), 10)
+        # processor 2 has the min waiting time, should generate an exception and return None
+        self.assertEqual(self.processor_2.process(5), None)
 
     def test_batch(self):
         def create_bulk_request(n, processor):
@@ -24,13 +26,16 @@ class TestBatchProcessor(unittest.TestCase):
 
         threads = []
         for i in range(200):
-            t = Thread(target=create_bulk_request, args=(i, self.processor))
+            t = Thread(target=create_bulk_request, args=(i, self.processor_1))
             t.start()
             threads.append(t)
 
         for t in threads:
             t.join()
 
+    def tearDown(self):
+        self.processor_1.terminate()
+        self.processor_2.terminate()
 
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
